/** BGEN file reader
 * @file bgen.h
 * @author Danilo Horta
 * @copyright The MIT License (MIT)
 *
 * The MIT License (MIT)
 *
 * Copyright (c) 2018 Danilo Horta
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef BGEN_H
#define BGEN_H

/** Major bgen version. */
#define BGEN_VERSION_MAJOR 3
/** Minor bgen version. */
#define BGEN_VERSION_MINOR 0
/** Minor bgen version. */
#define BGEN_VERSION_PATCH 3
/** Bgen version. */
#define BGEN_VERSION "3.0.3"

#ifdef __cplusplus
extern "C"
{
#endif

#include "bgen/api.h"
#include "bgen/depr.h"
#include "bgen/file.h"
#include "bgen/geno.h"
#include "bgen/meta.h"
#include "bgen/platform.h"
#include "bgen/str.h"

#ifdef __cplusplus
}
#endif

static_assert(sizeof(int) >= 4, "Code relies on int being at least 4 bytes");

#endif /* BGEN_H */
